@@ -99,7 +99,7 @@
 #' 
 #' @export
 #' @examples
-#' \donttest{
+#' #START_TAG_TEST
 #' @example examples/FlexTableExample.R
 #' @example examples/agg.mtcars.FlexTable.R
 #' @example examples/setFlexTableBackgroundColors.R
@@ -114,10 +114,10 @@
 #' , \code{\link{addFlexTable.pptx}}, \code{\link{addFlexTable.bsdoc}}
 FlexTable = function(data, numrow, numcol
 	, header.columns = TRUE, add.rownames = FALSE
-	, body.cell.props = cellProperties(padding=1)
+	, body.cell.props = cellProperties()
 	, body.par.props = parProperties(padding=0)
 	, body.text.props = textProperties()
-	, header.cell.props = cellProperties(padding=1)
+	, header.cell.props = cellProperties()
 	, header.par.props = parProperties(padding=0)
 	, header.text.props = textProperties( font.weight= "bold" )
 ){
