@@ -54,6 +54,7 @@ public class BootstrapPage {
 	private BootstrapMenu headerMenu;
 	private LinkedList<ParagraphSet> footer;
 
+	private boolean addTOC = false;
 	public BootstrapPage ( String title, String charset, NumberingDefinition numberingDefinition, String desc, String kwds ) throws IOException {
 		this.title = title;
 		titles = new TOC(this.title);
@@ -67,8 +68,8 @@ public class BootstrapPage {
 		list_id = 1;
 		counters = new Vector<String>();
 		numbDefinition = numberingDefinition;
-		jscodes.add("$(document).ready(function() {$('.tip').tooltip();});");
-		csscodes.add(".tip::before{counter-increment:counter-tip;content:\"*\";vertical-align:super;}");
+		jscodes.add("$(document).ready(function() {$('.tip').tooltip();});var raphael_tooltip = $('#gtooltip').hide();var tooltipHTML = '';var tooltipOVER = false;$(document).mousemove(function(e){if (tooltipOVER){raphael_tooltip.css('left', e.pageX+20).css('top', e.pageY+20);raphael_tooltip.html(tooltipHTML);}});function addTip(node, txt){$(node).mouseenter(function(){tooltipHTML = txt;raphael_tooltip.fadeIn();tooltipOVER = true;}).mouseleave(function(){raphael_tooltip.fadeOut(200);tooltipOVER = false;});}");
+		csscodes.add("#gtooltip{position:absolute;border:1px solid gray;background-color:white;z-index:1000;max-width:400px;};.tip::before{counter-increment:counter-tip;content:\"*\";vertical-align:super;};");
 		footer = new LinkedList<ParagraphSet>();
 		headerMenu = null;
 		description = desc;
@@ -131,6 +132,10 @@ public class BootstrapPage {
 		return addHTML4R(elt);
 	}
 	
+	public void addTOC(){
+		addTOC = true;
+	}
+	
 	public void setCharset(String charset ){
 		this.charset = charset;
 	}
@@ -248,20 +253,25 @@ public class BootstrapPage {
         output.write( getHead() );
 		output.write("<body>");
 		output.write("<a class=\"sr-only sr-only-focusable\" href=\"#content\">Skip to main content</a>");
-		
+		output.write("<div id=\"gtooltip\"></div>");
 		if( headerMenu != null ) output.write(headerMenu.getHTML());
 
 		
 		output.write("<div class=\"container bs-docs-container\">");//container
 		    output.write("<div class=\"row\">");//row
-		        output.write("<div class=\"col-md-9\" role=\"main\">");;
-
-		        output.write(mainContent);
-		        
+		    
+		    if( addTOC ) {
+		        output.write("<div class=\"col-md-9\" role=\"main\">");
+		        	output.write(mainContent);
 		        output.write("</div>");//col-md-9
-		    output.write("<div class=\"col-md-3\">");
-		        output.write(titles.getHTML());
-	        output.write("</div>");
+			    output.write("<div class=\"col-md-3\">");
+			        output.write(titles.getHTML());
+		        output.write("</div>");
+		    } else {
+		    	output.write("<div class=\"col-md-12\" role=\"main\">");
+		    	output.write(mainContent);
+		    	output.write("</div>");
+		    }
 
 	        output.write("</div>");//row
         output.write("</div>");//container
