@@ -69,6 +69,21 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 		double height_emu = dims[1] * 72 * 12700;height_emu = height_emu / physicalHeightDpi;
 		this.setExt((long)width_emu, (long)height_emu);
 		
+	}
+	
+	public Image(String filename, double w, double h) throws Exception {
+		super();
+		
+		this.filename = filename;
+		
+		File file = new File(filename);
+		image_bytes = org.lysis.reporters.img.Imageutils.convertImageToByteArray(file);
+		
+		
+		double width_emu = w * 72 * 12700 ;
+		double height_emu = h * 72 * 12700;
+		this.setExt((long)width_emu, (long)height_emu);
+		
 	}
 	public long nextUniqueId(){
 		return unique_id+2;
